<no title> — cis_interface 0.3.0 documentation

Model YAML:

    1
    2
    3
    4
    5
    6
    7
    ---

    model:
      name: server
      language: python
      args: ./src/server.py
      is_server: True  # Creates a RPC server queue called "server"

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    ---

    model:
      name: client
      language: python
      args:
        - ./src/client.py
        - 3  # Pass the number of iterations that should be performed
      client_of: server  # Creates an RPC client queue "server_client"
      outputs: output_log

    connections:
      input: output_log
      output: client_output.txt
      in_temp: True

(Example in other languages)